@@ -367,9 +367,6 @@ extern Client *clients;
 extern unsigned int client_count;
 
 Display                 *clientGetXDisplay                      (Client *);
-void                     clientClearLastOpTime                  (Client *);
-void                     clientUpdateWinState                   (Client *,
-                                                                 XClientMessageEvent *);
 void                     clientUpdateUrgency                    (Client *);
 void                     clientCoordGravitate                   (Client *,
                                                                  int,
@@ -396,7 +393,8 @@ void                     clientApplyMWMHints                    (Client *,
 void                     clientGetWMNormalHints                 (Client *,
                                                                  gboolean);
 void                     clientGetWMProtocols                   (Client *);
-void                     clientUpdateIcon                       (Client *);
+void                     clientUpdateIcon                       (Client *,
+                                                                 gboolean);
 void                     clientSaveSizePos                      (Client *);
 gboolean                 clientRestoreSizePos                   (Client *);
 Client                  *clientFrame                            (DisplayInfo *,
@@ -502,7 +500,6 @@ xfwmPixmap *             clientGetButtonPixmap                  (Client *,
 int                      clientGetButtonState                   (Client *,
                                                                  int,
                                                                  int);
-Client                  *clientGetLeader                        (Client *);
 gboolean                 clientGetGtkFrameExtents               (Client *);
 gboolean                 clientGetGtkHideTitlebar               (Client *);
 #ifdef HAVE_LIBSTARTUP_NOTIFICATION
