@@ -1702,7 +1702,7 @@ handlePropertyNotify (DisplayInfo *display_info, XPropertyEvent * ev)
                 }
                 if ((c->wmhints->flags & IconPixmapHint) && (screen_info->params->show_app_icon))
                 {
-                    clientUpdateIcon (c);
+                    clientUpdateIcon (c, FALSE);
                 }
                 if (HINTS_ACCEPT_INPUT (c->wmhints))
                 {
@@ -1804,7 +1804,7 @@ handlePropertyNotify (DisplayInfo *display_info, XPropertyEvent * ev)
                  ((ev->atom == display_info->atoms[NET_WM_ICON]) ||
                   (ev->atom == display_info->atoms[KWM_WIN_ICON])))
         {
-            clientUpdateIcon (c);
+            clientUpdateIcon (c, FALSE);
         }
         else if (ev->atom == display_info->atoms[GTK_FRAME_EXTENTS])
         {
@@ -1833,7 +1833,7 @@ handlePropertyNotify (DisplayInfo *display_info, XPropertyEvent * ev)
                 }
             }
         }
-#ifdef HAVE_STARTUP_NOTIFICATION
+#ifdef HAVE_LIBSTARTUP_NOTIFICATION
         else if (ev->atom == display_info->atoms[NET_STARTUP_ID])
         {
             if (c->startup_id)
@@ -1843,7 +1843,7 @@ handlePropertyNotify (DisplayInfo *display_info, XPropertyEvent * ev)
             }
             getWindowStartupId (display_info, c->window, &c->startup_id);
         }
-#endif /* HAVE_STARTUP_NOTIFICATION */
+#endif /* HAVE_LIBSTARTUP_NOTIFICATION */
 #ifdef HAVE_XSYNC
         else if (ev->atom == display_info->atoms[NET_WM_SYNC_REQUEST_COUNTER])
         {
@@ -2369,7 +2369,6 @@ menu_callback (Menu * menu, MenuOp op, Window xid, gpointer menu_data, gpointer
                 break;
             case MENU_OP_STICK:
                 clientToggleSticky (c, TRUE);
-                frameQueueDraw (c, FALSE);
                 break;
             case MENU_OP_WORKSPACES:
                 clientSetWorkspace (c, GPOINTER_TO_INT (item_data), TRUE);
@@ -2397,9 +2396,9 @@ menu_callback (Menu * menu, MenuOp op, Window xid, gpointer menu_data, gpointer
                 clientToggleFullscreen (c);
                 break;
             default:
-                frameQueueDraw (c, FALSE);
                 break;
         }
+        frameQueueDraw (c, FALSE);
     }
     else
     {
