@@ -105,7 +105,9 @@ clientGetTopMostFocusable (ScreenInfo *screen_info, guint layer, GList * exclude
             }
             else if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_VISIBLE))
             {
-                if (clientSelectMask (c, NULL, 0, WINDOW_REGULAR_FOCUSABLE))
+                if (clientSelectMask (c, NULL,
+                                      SEARCH_INCLUDE_SKIP_PAGER | SEARCH_INCLUDE_SKIP_TASKBAR,
+                                      WINDOW_REGULAR_FOCUSABLE))
                 {
                     top_client.prefered = c;
                 }
@@ -663,12 +665,6 @@ clientGetFocus (void)
     return (client_focus);
 }
 
-Client *
-clientGetFocusPending (void)
-{
-    return (pending_focus);
-}
-
 Client *
 clientGetFocusOrPending (void)
 {
