@@ -116,7 +116,7 @@ setupLog (gboolean debug)
     }
     else
     {
-        logfile = "/dev/null";
+        logfile = g_strdup ("/dev/null");
     }
 
     fd = dup(fileno(stderr));
@@ -138,9 +138,9 @@ setupLog (gboolean debug)
     if (debug)
     {
         g_print ("Logging to %s\n", logfile);
-        g_free (logfile);
     }
 
+    g_free (logfile);
     return TRUE;
 }
 #endif /* DEBUG */
@@ -250,45 +250,6 @@ ensure_basedir_spec (void)
 
     g_free (new);
 
-    /* copy xfwm4rc */
-
-    old = xfce_get_userfile ("xfwm4rc", NULL);
-
-    if (g_file_test (old, G_FILE_TEST_EXISTS))
-    {
-        FILE *r, *w;
-
-        g_strlcpy (path, "xfce4/xfwm4/xfwm4rc", PATH_MAX);
-        new = xfce_resource_save_location (XFCE_RESOURCE_CONFIG, path, FALSE);
-
-        r = fopen (old, "r");
-        w = fopen (new, "w");
-
-        g_free (new);
-
-        if (w && r)
-        {
-            int c;
-
-            while ((c = getc (r)) != EOF)
-            {
-                putc (c, w);
-            }
-        }
-
-        if (r)
-        {
-            fclose (r);
-        }
-
-        if (w)
-        {
-            fclose (w);
-        }
-    }
-
-    g_free (old);
-
     /* copy saved session data */
 
     new = xfce_resource_save_location (XFCE_RESOURCE_CACHE, "sessions", FALSE);
@@ -415,8 +376,6 @@ compositor_callback (const gchar  *name,
                      gpointer      user_data,
                      GError      **error)
 {
-    gboolean succeed = TRUE;
-
     g_return_val_if_fail (value != NULL, FALSE);
 
     if (strcmp (value, "off") == 0)
@@ -430,10 +389,10 @@ compositor_callback (const gchar  *name,
     else
     {
         g_set_error (error, XFWM4_ERROR, 0, "Unrecognized compositor option \"%s\"", value);
-        succeed = FALSE;
+        return FALSE;
     }
 
-    return succeed;
+    return TRUE;
 }
 
 static gboolean
@@ -442,8 +401,6 @@ vblank_callback (const gchar  *name,
                  gpointer      user_data,
                  GError      **error)
 {
-    gboolean succeed = TRUE;
-
     g_return_val_if_fail (value != NULL, FALSE);
 
 #ifdef HAVE_PRESENT_EXTENSION
@@ -467,10 +424,10 @@ vblank_callback (const gchar  *name,
     else
     {
         g_set_error (error, XFWM4_ERROR, 0, "Unrecognized compositor option \"%s\"", value);
-        succeed = FALSE;
+        return FALSE;
     }
 
-    return succeed;
+    return TRUE;
 }
 
 static void
@@ -488,7 +445,7 @@ init_compositor_screen (ScreenInfo *screen_info)
     {
         gboolean xfwm4_compositor;
 
-        xfwm4_compositor = TRUE;
+        xfwm4_compositor = FALSE;
         if (screen_info->params->use_compositing)
         {
             /* Enable compositor if "use compositing" is enabled */
