@@ -372,13 +372,6 @@ menu_item_connect (GtkWidget * item, MenuData * item_data)
     return (item);
 }
 
-gboolean
-menu_is_opened (void)
-{
-    TRACE ("entering");
-    return (menu_open != NULL);
-}
-
 gboolean
 menu_check_and_close (void)
 {
