@@ -299,7 +299,7 @@ clientConstrainRatio (Client * c, int handle)
             {
                 c->height -= delta;
             }
-            else
+            else if (miny)
             {
                 delta = MAKE_MULT (minx * c->height / miny - c->width, xinc);
                 if (!(c->size->flags & PMaxSize) ||
@@ -326,7 +326,7 @@ clientConstrainRatio (Client * c, int handle)
             {
                 c->width -= delta;
             }
-            else
+            else if (maxx)
             {
                 delta = MAKE_MULT (c->width * maxy / maxx - c->height, yinc);
                 if (!(c->size->flags & PMaxSize) ||
@@ -1376,7 +1376,6 @@ clientResizeEventFilter (XfwmEvent *event, gpointer data)
     ScreenInfo *screen_info;
     DisplayInfo *display_info;
     Client *c;
-    GdkRectangle rect;
     MoveResizeData *passdata;
     eventFilterStatus status;
     int prev_width, prev_height;
@@ -1420,8 +1419,6 @@ clientResizeEventFilter (XfwmEvent *event, gpointer data)
             || (passdata->handle == CORNER_COUNT + SIDE_LEFT)) ?
         1 : 0;
 
-    myScreenFindMonitorAtPoint (screen_info, cx, cy, &rect);
-
     /* Store previous values in case the resize puts the window title off bounds */
     prev_width = c->width;
     prev_height = c->height;
