@@ -71,10 +71,11 @@ overlap (int x0, int y0, int x1, int y1, int tx0, int ty0, int tx1, int ty1)
             * segment_overlap (y0, y1, ty0, ty1));
 }
 
-static void
+static inline void
 set_rectangle (GdkRectangle * rect, gint x, gint y, gint width, gint height)
 {
-    g_return_if_fail (rect != NULL);
+    if (rect == NULL)
+        return;
 
     rect->x = x;
     rect->y = y;
@@ -101,41 +102,26 @@ strutsToRectangles (Client *c,
         return FALSE;
     }
 
-    if (left)
-    {
-        set_rectangle (left,
-                       0,
-                       c->struts[STRUTS_LEFT_START_Y],
-                       c->struts[STRUTS_LEFT],
-                       c->struts[STRUTS_LEFT_END_Y] - c->struts[STRUTS_LEFT_START_Y]);
-    }
-
-    if (right)
-    {
-        set_rectangle (right,
-                       screen_info->width - c->struts[STRUTS_RIGHT],
-                       c->struts[STRUTS_RIGHT_START_Y],
-                       c->struts[STRUTS_RIGHT],
-                       c->struts[STRUTS_RIGHT_END_Y] - c->struts[STRUTS_RIGHT_START_Y]);
-    }
-
-    if (top)
-    {
-        set_rectangle (top,
-                       c->struts[STRUTS_TOP_START_X],
-                       0,
-                       c->struts[STRUTS_TOP_END_X] - c->struts[STRUTS_TOP_START_X],
-                       c->struts[STRUTS_TOP]);
-    }
-
-    if (bottom)
-    {
-        set_rectangle (bottom,
-                       c->struts[STRUTS_BOTTOM_START_X],
-                       screen_info->height - c->struts[STRUTS_BOTTOM],
-                       c->struts[STRUTS_BOTTOM_END_X] - c->struts[STRUTS_BOTTOM_START_X],
-                       c->struts[STRUTS_BOTTOM]);
-    }
+    set_rectangle (left,
+                   0,
+                   c->struts[STRUTS_LEFT_START_Y],
+                   c->struts[STRUTS_LEFT],
+                   c->struts[STRUTS_LEFT_END_Y] - c->struts[STRUTS_LEFT_START_Y]);
+    set_rectangle (right,
+                   screen_info->width - c->struts[STRUTS_RIGHT],
+                   c->struts[STRUTS_RIGHT_START_Y],
+                   c->struts[STRUTS_RIGHT],
+                   c->struts[STRUTS_RIGHT_END_Y] - c->struts[STRUTS_RIGHT_START_Y]);
+    set_rectangle (top,
+                   c->struts[STRUTS_TOP_START_X],
+                   0,
+                   c->struts[STRUTS_TOP_END_X] - c->struts[STRUTS_TOP_START_X],
+                   c->struts[STRUTS_TOP]);
+    set_rectangle (bottom,
+                   c->struts[STRUTS_BOTTOM_START_X],
+                   screen_info->height - c->struts[STRUTS_BOTTOM],
+                   c->struts[STRUTS_BOTTOM_END_X] - c->struts[STRUTS_BOTTOM_START_X],
+                   c->struts[STRUTS_BOTTOM]);
 
     return TRUE;
 }
@@ -218,17 +204,16 @@ clientsHaveOverlap (Client *c1, Client *c2)
     return gdk_rectangle_intersect (&win1, &win2, NULL);
 }
 
-void
-clientMaxSpaceForGeometry (Client *c,
-                           GdkRectangle *rect,
-                           GdkRectangle *dest)
+GdkRectangle
+clientMaxSpaceForGeometry (Client *c, GdkRectangle rect)
 {
-    g_return_if_fail (c != NULL);
-    g_return_if_fail (rect != NULL);
-    g_return_if_fail (dest != NULL);
+    GdkRectangle dest = { 0 };
 
-    myScreenMaxSpaceForGeometry (c->screen_info, rect, dest);
-    clientMaxSpace (c, dest);
+    g_return_val_if_fail (c != NULL, dest);
+
+    myScreenMaxSpaceForGeometry (c->screen_info, &rect, &dest);
+    clientMaxSpace (c, &dest);
+    return dest;
 }
 
 static void
@@ -315,7 +300,7 @@ clientMaxSpace (Client *c, GdkRectangle *area)
     g_return_if_fail (c != NULL);
     g_return_if_fail (area != NULL);
 
-    TRACE ("client \"%s\" (0x%lx) %s", c->name, c->window);
+    TRACE ("client \"%s\" (0x%lx)", c->name, c->window);
 
     screen_info = c->screen_info;
 
@@ -351,12 +336,11 @@ clientConstrainPos (Client * c, gboolean show_full)
     Client *c2;
     ScreenInfo *screen_info;
     guint i;
-    gint cx, cy;
     gint frame_top, frame_left;
     gint title_visible;
     gint screen_width, screen_height;
     guint ret;
-    GdkRectangle top, left, right, bottom, win, monitor;
+    GdkRectangle win, monitor;
     gint min_visible;
 
     g_return_val_if_fail (c != NULL, 0);
@@ -380,9 +364,10 @@ clientConstrainPos (Client * c, gboolean show_full)
     min_visible = MAX (title_visible, CLIENT_MIN_VISIBLE);
     ret = 0;
 
-    cx = win.x + (win.width / 2);
-    cy = win.y + (win.height / 2);
-    myScreenFindMonitorAtPoint (screen_info, cx, cy, &monitor);
+    myScreenFindMonitorAtPoint (screen_info,
+                                win.x + (win.width / 2),
+                                win.y + (win.height / 2),
+                                &monitor);
 
     screen_width = screen_info->width;
     screen_height = screen_info->height;
@@ -397,7 +382,8 @@ clientConstrainPos (Client * c, gboolean show_full)
     {
         for (c2 = screen_info->clients, i = 0; i < screen_info->client_count; c2 = c2->next, i++)
         {
-            if ((c2 == c) || !strutsToRectangles (c2, &left, &right, &top, &bottom))
+            GdkRectangle right, bottom;
+            if ((c2 == c) || !strutsToRectangles (c2, NULL, &right, NULL, &bottom))
             {
                 continue;
             }
@@ -451,7 +437,8 @@ clientConstrainPos (Client * c, gboolean show_full)
 
         for (c2 = screen_info->clients, i = 0; i < screen_info->client_count; c2 = c2->next, i++)
         {
-            if ((c2 == c) || !strutsToRectangles (c2, &left, &right, &top, &bottom))
+            GdkRectangle top, left;
+            if ((c2 == c) || !strutsToRectangles (c2, &left, NULL, &top, NULL))
             {
                 continue;
             }
@@ -514,6 +501,7 @@ clientConstrainPos (Client * c, gboolean show_full)
         /* Struts and other partial struts */
         for (c2 = screen_info->clients, i = 0; i < screen_info->client_count; c2 = c2->next, i++)
         {
+            GdkRectangle top, left, right, bottom;
             if ((c2 == c) || !strutsToRectangles (c2, &left, &right, &top, &bottom))
             {
                 continue;
@@ -970,6 +958,12 @@ clientFill (Client * c, int fill_type)
 
     TRACE ("client \"%s\" (0x%lx)", c->name, c->window);
 
+    /* don't change anything if the window isn't managed by us */
+    if (!FLAG_TEST (c->xfwm_flags, XFWM_FLAG_MANAGED))
+    {
+        return;
+    }
+
     if (!CLIENT_CAN_FILL_WINDOW (c))
     {
         return;
@@ -1149,8 +1143,5 @@ clientFill (Client * c, int fill_type)
     }
 
     TRACE ("fill size request: (%d,%d) %dx%d", wc.x, wc.y, wc.width, wc.height);
-    if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_MANAGED))
-    {
-        clientConfigure(c, &wc, mask, NO_CFG_FLAG);
-    }
+    clientConfigure(c, &wc, mask, NO_CFG_FLAG);
 }
