@@ -303,11 +303,17 @@ myScreenInit (DisplayInfo *display_info, GdkScreen *gscr, unsigned long event_ma
     {
         xfwmPixmapInit (screen_info, &screen_info->sides[i][ACTIVE]);
         xfwmPixmapInit (screen_info, &screen_info->sides[i][INACTIVE]);
+        
+        xfwmPixmapInit (screen_info, &screen_info->sides_stretch[i][ACTIVE]);
+        xfwmPixmapInit (screen_info, &screen_info->sides_stretch[i][INACTIVE]);
     }
     for (i = 0; i < CORNER_COUNT; i++)
     {
         xfwmPixmapInit (screen_info, &screen_info->corners[i][ACTIVE]);
         xfwmPixmapInit (screen_info, &screen_info->corners[i][INACTIVE]);
+
+        xfwmPixmapInit (screen_info, &screen_info->corners_stretch[i][ACTIVE]);
+        xfwmPixmapInit (screen_info, &screen_info->corners_stretch[i][INACTIVE]);
     }
     for (i = 0; i < BUTTON_COUNT; i++)
     {
@@ -836,7 +842,6 @@ myScreenGetXineramaMonitorGeometry (ScreenInfo *screen_info, gint monitor_num, G
 
     g_return_if_fail (screen_info != NULL);
     g_return_if_fail (rect != NULL);
-    g_return_if_fail (XineramaIsActive (myScreenGetXDisplay (screen_info)));
 
     infos = XineramaQueryScreens (myScreenGetXDisplay (screen_info), &n);
     if (infos == NULL || n <= 0 || monitor_num > n)
@@ -893,15 +898,15 @@ myScreenUpdateFontAttr (ScreenInfo *screen_info)
     pango_attr_list_insert (screen_info->pango_attr_list, attr);
 }
 
-gboolean
+void
 myScreenMaxSpaceForGeometry (ScreenInfo *screen_info,
                              GdkRectangle *rect,
                              GdkRectangle *dest)
 {
     GdkRectangle screen_rect;
 
-    g_return_val_if_fail (screen_info != NULL, FALSE);
-    g_return_val_if_fail (rect != NULL, FALSE);
+    g_return_if_fail (screen_info != NULL);
+    g_return_if_fail (rect != NULL);
 
     screen_rect.x = screen_info->params->xfwm_margins[STRUTS_LEFT];
     screen_rect.y = screen_info->params->xfwm_margins[STRUTS_TOP];
@@ -912,5 +917,5 @@ myScreenMaxSpaceForGeometry (ScreenInfo *screen_info,
                          screen_info->params->xfwm_margins[STRUTS_TOP] -
                          screen_info->params->xfwm_margins[STRUTS_BOTTOM];
 
-    return gdk_rectangle_intersect (&screen_rect, rect, dest);
+    gdk_rectangle_intersect (&screen_rect, rect, dest);
 }
