@@ -31,8 +31,11 @@
 #include "client.h"
 
 Client                  *clientGetTransient                     (Client *);
+gboolean                 clientIsDirectTransient                (Client *);
+gboolean                 clientIsTransientForGroup              (Client *);
 gboolean                 clientIsTransient                      (Client *);
 gboolean                 clientIsModal                          (Client *);
+gboolean                 clientIsModalForGroup                  (Client *);
 gboolean                 clientIsTransientOrModal               (Client *);
 gboolean                 clientIsValidTransientOrModal          (Client *);
 gboolean                 clientSameGroup                        (Client *,
@@ -43,14 +46,10 @@ gboolean                 clientSameName                         (Client *,
                                                                  Client *);
 gboolean                 clientSameApplication                  (Client *,
                                                                  Client *);
-gboolean                 clientIsTransientFor                   (Client *,
-                                                                 Client *);
 gboolean                 clientIsModalFor                       (Client *,
                                                                  Client *);
 gboolean                 clientIsTransientOrModalFor            (Client *,
                                                                  Client *);
-gboolean                 clientIsTransientForGroup              (Client *);
-gboolean                 clientIsModalForGroup                  (Client *);
 gboolean                 clientIsTransientOrModalForGroup       (Client *);
 gboolean                 clientTransientOrModalHasAncestor      (Client *,
                                                                  guint);
